Number Guesser Game
The Number Guesser Game is a python package that contains a simple and funny game, based on a few arithmetic operations this game will be able to guess the number in the player's mind.

Install
$ pip install guesser_game  
Usage
Open a Python console, import the module GuessMyNumber, create an instance of it and call its method play(). Now start to play and let this code guess the number you have in mind 😉

>> from guesser_game import GuessMyNumber
>>
>> my_game = GuessMyNumber()
>> my_game.play()
License
This project is licensed under the MIT License

Author
Wendy Navarrete